# Faas Supervisor

Input / Output data manager for FaaS functions.
Works in different cloud environments and allows different data providers.

Python package available at Pypi with the name **faas-supervisor**.